pub type EngineResult<T> = Result<T, EngineError>;Expand description
Convenience result type used throughout the remote multimodal engine.
Aliased Type
pub enum EngineResult<T> {
Ok(T),
Err(EngineError),
}pub type EngineResult<T> = Result<T, EngineError>;Convenience result type used throughout the remote multimodal engine.
pub enum EngineResult<T> {
Ok(T),
Err(EngineError),
}